summaryrefslogtreecommitdiff
path: root/include/GL/xmesa.h
diff options
context:
space:
mode:
authorBrian Paul <brian.paul@tungstengraphics.com>1999-11-24 18:36:14 +0000
committerBrian Paul <brian.paul@tungstengraphics.com>1999-11-24 18:36:14 +0000
commit2257a120133010f42b4d0c3eb78b6a46a579e55b (patch)
tree2eb047a8577b48d4703efa48ef5efc1772d97536 /include/GL/xmesa.h
parentb314d1d3af04a4d79bc2e1ce05dacd902ec999f2 (diff)
added XMesaMakeCurrent2(), XMesaGetCurrentReadBuffer(), bumped version to 3.3
Diffstat (limited to 'include/GL/xmesa.h')
-rw-r--r--include/GL/xmesa.h32
1 files changed, 26 insertions, 6 deletions
diff --git a/include/GL/xmesa.h b/include/GL/xmesa.h
index b25a2ace7e..4a2ed9ac25 100644
--- a/include/GL/xmesa.h
+++ b/include/GL/xmesa.h
@@ -1,8 +1,8 @@
-/* $Id: xmesa.h,v 1.1 1999/08/19 00:55:40 jtg Exp $ */
+/* $Id: xmesa.h,v 1.2 1999/11/24 18:36:14 brianp Exp $ */
/*
* Mesa 3-D graphics library
- * Version: 3.1
+ * Version: 3.3
*
* Copyright (C) 1999 Brian Paul All Rights Reserved.
*
@@ -27,8 +27,11 @@
/*
* $Log: xmesa.h,v $
- * Revision 1.1 1999/08/19 00:55:40 jtg
- * Initial revision
+ * Revision 1.2 1999/11/24 18:36:14 brianp
+ * added XMesaMakeCurrent2(), XMesaGetCurrentReadBuffer(), bumped version to 3.3
+ *
+ * Revision 1.1.1.1 1999/08/19 00:55:40 jtg
+ * Imported sources
*
* Revision 1.3 1999/02/24 22:43:27 jens
* Name changes to get XMesa to compile standalone inside XFree86
@@ -106,7 +109,7 @@ extern struct Library *XLibBase;
#define XMESA_MAJOR_VERSION 3
-#define XMESA_MINOR_VERSION 0
+#define XMESA_MINOR_VERSION 3
@@ -227,18 +230,35 @@ extern GLboolean XMesaMakeCurrent( XMesaContext c,
/*
+ * Bind two buffers (read and draw) to a context and make the
+ * context the current one.
+ * New in Mesa 3.3
+ */
+extern GLboolean XMesaMakeCurrent2( XMesaContext c,
+ XMesaBuffer drawBuffer,
+ XMesaBuffer readBuffer );
+
+
+/*
* Return a handle to the current context.
*/
extern XMesaContext XMesaGetCurrentContext( void );
/*
* Return handle to the current buffer.
*/
extern XMesaBuffer XMesaGetCurrentBuffer( void );
/*
+ * Return handle to the current read buffer.
+ * New in Mesa 3.3
+ */
+extern XMesaBuffer XMesaGetCurrentReadBuffer( void );
+
+
+/*
* Swap the front and back buffers for the given buffer. No action is
* taken if the buffer is not double buffered.
*/
@@ -227,18 +230,35 @@ extern GLboolean XMesaMakeCurrent( XMesaContext c,
extern XMesaContext XMesaGetCurrentContext( void );
/*
- * Return handle to the current buffer.
+ * Return handle to the current (draw) buffer.
*/
extern XMesaBuffer XMesaGetCurrentBuffer( void );